@@ -49,27 +49,19 @@ else:
 
 # Concat all languages (env + default locale),
 #  and here we have the languages and location of the translations
-#
 languages += DEFAULT_LANGUAGES
 mo_location = LOCALE_DIR
 
-#print "languages:", languages
-
 # Lets tell those details to gettext
 #  (nothing to change here for you)
 gettext.install (True,localedir=None, unicode=1)
 
-
-#gettext.bindtextdomain (APP_NAME,mo_location)
-#gettext.bindtextdomain(domain[, localedir])
-#gettext.find(domain[, localedir[, languages[, all]]])
 gettext.find(APP_NAME, mo_location)
 
 gettext.textdomain (APP_NAME)
 
-gettext.bind_textdomain_codeset(APP_NAME, "iso-8859-15")
+gettext.bind_textdomain_codeset(APP_NAME, "UTF-8")
 
-#language = gettext.translation (APP_NAME, mo_location, languages = languages, fallback = True)
 language = gettext.translation (APP_NAME, mo_location, languages = languages, fallback = True)
 
 
