@@ -454,14 +454,13 @@ def MoveTrigger(direction):
 
 
 def About(ui):
-    QtGui.QMessageBox.about(ui, _("About")+" SleepAnalyser", _("Copyright 2010 by George Ruinelli with great support from the MAEMO community")+"\n"+\
-    _("Version:")+" "+str(data.version)+"-"+str(data.build)+"\n"+\
+    QtGui.QMessageBox.about(ui, _("About")+" SleepAnalyser "+str(data.version)+"-"+str(data.build), _("Copyright 2010 by George Ruinelli with great support from the MAEMO community")+"\n"+\
     _("Contact:")+" george@ruinelli.ch\n" +\
     _("Website:")+" http://www.ruinelli.ch/sleepanalyser/\n\n"+\
-    _("Feedback and donations are very welcome!")+"\n\n"+\
     _("Translations:")+\
     "\nEnglish, Deutsch: George Ruinelli\n"+\
-    "Francais, Dutch: Fred Kwame Ayanful")
+    "Francais: Fred Kwame Ayanfu & Guy Roussil\n"+\
+    "Dutch: Fred Kwame Ayanful")
 
 
 
